HtmlToMarkdown. CodeBlockStyle
(html_to_markdown v3.11.4)
Code block fence style in Markdown output.
Determines how code blocks (<pre><code>) are rendered in Markdown.
Summary
Functions
Fenced code blocks with triple backticks. Default (GFM). Supports language hints.
Indented code blocks (4 spaces). CommonMark standard.
Fenced code blocks with tildes (~~~). Supports language hints.
Returns the serde wire value this variant carries on the JSON boundary (see wire_variant_value in alef's naming module) -- distinct from the atom's Elixir spelling.
Types
Functions
@spec backticks() :: t()
Fenced code blocks with triple backticks. Default (GFM). Supports language hints.
@spec indented() :: t()
Indented code blocks (4 spaces). CommonMark standard.
@spec tildes() :: t()
Fenced code blocks with tildes (~~~). Supports language hints.
Returns the serde wire value this variant carries on the JSON boundary (see wire_variant_value in alef's naming module) -- distinct from the atom's Elixir spelling.