HtmlToMarkdown.TierStrategy (html_to_markdown v3.7.2)

Controls which conversion tier is used.

Summary

Types

t()

Controls which conversion tier is used.

Functions

Automatically pick the best tier for the input (default).

Force the Tier-1 byte scanner; if it bails, fall back to Tier-2. Testkit-only; not stable API.

Always use the Tier-2 (tl::parse + walk) path, skipping Tier-1.

Types

t()

@type t() :: :auto | :tier2 | :tier1

Controls which conversion tier is used.

Functions

auto()

@spec auto() :: t()

Automatically pick the best tier for the input (default).

tier1()

@spec tier1() :: t()

Force the Tier-1 byte scanner; if it bails, fall back to Tier-2. Testkit-only; not stable API.

tier2()

@spec tier2() :: t()

Always use the Tier-2 (tl::parse + walk) path, skipping Tier-1.